==> nbdkit_1.22.4.orig.tar.gz: nbdkit-1.22.4/tests/test-rate.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright (C) 2018-2020 Red Hat Inc.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

source ./functions.sh
set -e
set -x

requires qemu-img --version

files="rate.img rate.time rate.err"
rm -f $files
cleanup_fn rm -f $files

# This should take no less than 20 seconds to run:
#   (8 * 25 * 1024 * 1024) / (10 * 1024 * 1024) = 20
# but because the bucket is full at the start the filter will
# burst for a couple of seconds to begin with, therefore the
# expected minimum time is more like 18-19 seconds.

start_t=$SECONDS
nbdkit -U - --filter=rate pattern 25M rate=10M \
       --run 'qemu-img convert -p $nbd rate.img'
end_t=$SECONDS

if [ $((end_t - start_t)) -lt 18 ]; then
    echo "$0: rate filter failed: command took $seconds seconds, expected about 20"
    exit 1
fi

==> nbdkit_1.32.3.orig.tar.gz: nbdkit-1.32.3/tests/test-rate.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright (C) 2018-2020 Red Hat Inc.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

source ./functions.sh
set -e
set -x

requires_run
requires nbdcopy --version

files="rate.img rate.time rate.err"
rm -f $files
cleanup_fn rm -f $files

# This should take no less than 20 seconds to run:
#   (8 * 25 * 1024 * 1024) / (10 * 1024 * 1024) = 20
# but because the bucket is full at the start the filter will
# burst for a couple of seconds to begin with, therefore the
# expected minimum time is more like 18-19 seconds.
#
# Note that we use the blocksize filter because nbdcopy issues very
# large requests, causing lumpy long sleeps.  The filter breaks these
# data requests up.

start_t=$SECONDS
nbdkit -U - \
       --filter=blocksize --filter=rate \
       pattern 25M \
       maxdata=65536 \
       rate=10M burstiness=2.0 \
       --run 'nbdcopy "$uri" rate.img'
end_t=$SECONDS

if [ $((end_t - start_t)) -lt 18 ]; then
    echo "$0: rate filter failed: command took $seconds seconds, expected about 20"
    exit 1
fi
